==> zio-aws-lexmodelsv2_2.12-5.19.8.2-sources.jar: zio/aws/lexmodelsv2/model/UpdateIntentRequest.scala <==
package zio.aws.lexmodelsv2.model
import zio.aws.lexmodelsv2.model.primitives.{
  LocaleId,
  IntentSignature,
  DraftBotVersion,
  Description,
  Name,
  Id
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateIntentRequest(
    intentId: Id,
    intentName: Name,
    description: Optional[Description] = Optional.Absent,
    parentIntentSignature: Optional[IntentSignature] = Optional.Absent,
    sampleUtterances: Optional[
      Iterable[zio.aws.lexmodelsv2.model.SampleUtterance]
    ] = Optional.Absent,
    dialogCodeHook: Optional[zio.aws.lexmodelsv2.model.DialogCodeHookSettings] =
      Optional.Absent,
    fulfillmentCodeHook: Optional[
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings
    ] = Optional.Absent,
    slotPriorities: Optional[Iterable[zio.aws.lexmodelsv2.model.SlotPriority]] =
      Optional.Absent,
    intentConfirmationSetting: Optional[
      zio.aws.lexmodelsv2.model.IntentConfirmationSetting
    ] = Optional.Absent,
    intentClosingSetting: Optional[
      zio.aws.lexmodelsv2.model.IntentClosingSetting
    ] = Optional.Absent,
    inputContexts: Optional[Iterable[zio.aws.lexmodelsv2.model.InputContext]] =
      Optional.Absent,
    outputContexts: Optional[
      Iterable[zio.aws.lexmodelsv2.model.OutputContext]
    ] = Optional.Absent,
    kendraConfiguration: Optional[
      zio.aws.lexmodelsv2.model.KendraConfiguration
    ] = Optional.Absent,
    botId: Id,
    botVersion: DraftBotVersion,
    localeId: LocaleId,
    initialResponseSetting: Optional[
      zio.aws.lexmodelsv2.model.InitialResponseSetting
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest = {
    import UpdateIntentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
      .builder()
      .intentId(Id.unwrap(intentId): java.lang.String)
      .intentName(Name.unwrap(intentName): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        parentIntentSignature.map(value =>
          IntentSignature.unwrap(value): java.lang.String
        )
      )(_.parentIntentSignature)
      .optionallyWith(
        sampleUtterances.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sampleUtterances)
      .optionallyWith(dialogCodeHook.map(value => value.buildAwsValue()))(
        _.dialogCodeHook
      )
      .optionallyWith(fulfillmentCodeHook.map(value => value.buildAwsValue()))(
        _.fulfillmentCodeHook
      )
      .optionallyWith(
        slotPriorities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.slotPriorities)
      .optionallyWith(
        intentConfirmationSetting.map(value => value.buildAwsValue())
      )(_.intentConfirmationSetting)
      .optionallyWith(intentClosingSetting.map(value => value.buildAwsValue()))(
        _.intentClosingSetting
      )
      .optionallyWith(
        inputContexts.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.inputContexts)
      .optionallyWith(
        outputContexts.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.outputContexts)
      .optionallyWith(kendraConfiguration.map(value => value.buildAwsValue()))(
        _.kendraConfiguration
      )
      .botId(Id.unwrap(botId): java.lang.String)
      .botVersion(DraftBotVersion.unwrap(botVersion): java.lang.String)
      .localeId(LocaleId.unwrap(localeId): java.lang.String)
      .optionallyWith(
        initialResponseSetting.map(value => value.buildAwsValue())
      )(_.initialResponseSetting)
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly =
    zio.aws.lexmodelsv2.model.UpdateIntentRequest.wrap(buildAwsValue())
}
object UpdateIntentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.UpdateIntentRequest =
      zio.aws.lexmodelsv2.model.UpdateIntentRequest(
        intentId,
        intentName,
        description.map(value => value),
        parentIntentSignature.map(value => value),
        sampleUtterances.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dialogCodeHook.map(value => value.asEditable),
        fulfillmentCodeHook.map(value => value.asEditable),
        slotPriorities.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        intentConfirmationSetting.map(value => value.asEditable),
        intentClosingSetting.map(value => value.asEditable),
        inputContexts.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        outputContexts.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        kendraConfiguration.map(value => value.asEditable),
        botId,
        botVersion,
        localeId,
        initialResponseSetting.map(value => value.asEditable)
      )
    def intentId: Id
    def intentName: Name
    def description: Optional[Description]
    def parentIntentSignature: Optional[IntentSignature]
    def sampleUtterances
        : Optional[List[zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly]]
    def dialogCodeHook
        : Optional[zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly]
    def fulfillmentCodeHook: Optional[
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly
    ]
    def slotPriorities
        : Optional[List[zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly]]
    def intentConfirmationSetting
        : Optional[zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly]
    def intentClosingSetting
        : Optional[zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly]
    def inputContexts
        : Optional[List[zio.aws.lexmodelsv2.model.InputContext.ReadOnly]]
    def outputContexts
        : Optional[List[zio.aws.lexmodelsv2.model.OutputContext.ReadOnly]]
    def kendraConfiguration
        : Optional[zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly]
    def botId: Id
    def botVersion: DraftBotVersion
    def localeId: LocaleId
    def initialResponseSetting
        : Optional[zio.aws.lexmodelsv2.model.InitialResponseSetting.ReadOnly]
    def getIntentId: ZIO[Any, Nothing, Id] = ZIO.succeed(intentId)
    def getIntentName: ZIO[Any, Nothing, Name] = ZIO.succeed(intentName)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getParentIntentSignature: ZIO[Any, AwsError, IntentSignature] =
      AwsError.unwrapOptionField("parentIntentSignature", parentIntentSignature)
    def getSampleUtterances: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly
    ]] = AwsError.unwrapOptionField("sampleUtterances", sampleUtterances)
    def getDialogCodeHook: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly
    ] = AwsError.unwrapOptionField("dialogCodeHook", dialogCodeHook)
    def getFulfillmentCodeHook: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly
    ] = AwsError.unwrapOptionField("fulfillmentCodeHook", fulfillmentCodeHook)
    def getSlotPriorities: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly
    ]] = AwsError.unwrapOptionField("slotPriorities", slotPriorities)
    def getIntentConfirmationSetting: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly
    ] = AwsError.unwrapOptionField(
      "intentConfirmationSetting",
      intentConfirmationSetting
    )
    def getIntentClosingSetting: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly
    ] = AwsError.unwrapOptionField("intentClosingSetting", intentClosingSetting)
    def getInputContexts: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.InputContext.ReadOnly
    ]] = AwsError.unwrapOptionField("inputContexts", inputContexts)
    def getOutputContexts: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.OutputContext.ReadOnly
    ]] = AwsError.unwrapOptionField("outputContexts", outputContexts)
    def getKendraConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("kendraConfiguration", kendraConfiguration)
    def getBotId: ZIO[Any, Nothing, Id] = ZIO.succeed(botId)
    def getBotVersion: ZIO[Any, Nothing, DraftBotVersion] =
      ZIO.succeed(botVersion)
    def getLocaleId: ZIO[Any, Nothing, LocaleId] = ZIO.succeed(localeId)
    def getInitialResponseSetting: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.InitialResponseSetting.ReadOnly
    ] = AwsError.unwrapOptionField(
      "initialResponseSetting",
      initialResponseSetting
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ) extends zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly {
    override val intentId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.intentId())
    override val intentName: Name =
      zio.aws.lexmodelsv2.model.primitives.Name(impl.intentName())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Description(value))
    override val parentIntentSignature: Optional[IntentSignature] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parentIntentSignature())
        .map(value =>
          zio.aws.lexmodelsv2.model.primitives.IntentSignature(value)
        )
    override val sampleUtterances
        : Optional[List[zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sampleUtterances())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lexmodelsv2.model.SampleUtterance.wrap(item)
          }.toList
        )
    override val dialogCodeHook
        : Optional[zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dialogCodeHook())
        .map(value =>
          zio.aws.lexmodelsv2.model.DialogCodeHookSettings.wrap(value)
        )
    override val fulfillmentCodeHook: Optional[
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.fulfillmentCodeHook())
      .map(value =>
        zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.wrap(value)
      )
    override val slotPriorities
        : Optional[List[zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.slotPriorities())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lexmodelsv2.model.SlotPriority.wrap(item)
          }.toList
        )
    override val intentConfirmationSetting: Optional[
      zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.intentConfirmationSetting())
      .map(value =>
        zio.aws.lexmodelsv2.model.IntentConfirmationSetting.wrap(value)
      )
    override val intentClosingSetting
        : Optional[zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.intentClosingSetting())
        .map(value =>
          zio.aws.lexmodelsv2.model.IntentClosingSetting.wrap(value)
        )
    override val inputContexts
        : Optional[List[zio.aws.lexmodelsv2.model.InputContext.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.inputContexts())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lexmodelsv2.model.InputContext.wrap(item)
          }.toList
        )
    override val outputContexts
        : Optional[List[zio.aws.lexmodelsv2.model.OutputContext.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.outputContexts())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lexmodelsv2.model.OutputContext.wrap(item)
          }.toList
        )
    override val kendraConfiguration
        : Optional[zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.kendraConfiguration())
        .map(value => zio.aws.lexmodelsv2.model.KendraConfiguration.wrap(value))
    override val botId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.botId())
    override val botVersion: DraftBotVersion =
      zio.aws.lexmodelsv2.model.primitives.DraftBotVersion(impl.botVersion())
    override val localeId: LocaleId =
      zio.aws.lexmodelsv2.model.primitives.LocaleId(impl.localeId())
    override val initialResponseSetting
        : Optional[zio.aws.lexmodelsv2.model.InitialResponseSetting.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.initialResponseSetting())
        .map(value =>
          zio.aws.lexmodelsv2.model.InitialResponseSetting.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ): zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lexmodelsv2_3-5.17.104.13-sources.jar: zio/aws/lexmodelsv2/model/UpdateIntentRequest.scala <==
package zio.aws.lexmodelsv2.model
import zio.aws.lexmodelsv2.model.primitives.{
  LocaleId,
  IntentSignature,
  DraftBotVersion,
  Description,
  Name,
  Id
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateIntentRequest(
    intentId: Id,
    intentName: Name,
    description: Option[Description] = None,
    parentIntentSignature: Option[IntentSignature] = None,
    sampleUtterances: Option[
      Iterable[zio.aws.lexmodelsv2.model.SampleUtterance]
    ] = None,
    dialogCodeHook: Option[zio.aws.lexmodelsv2.model.DialogCodeHookSettings] =
      None,
    fulfillmentCodeHook: Option[
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings
    ] = None,
    slotPriorities: Option[Iterable[zio.aws.lexmodelsv2.model.SlotPriority]] =
      None,
    intentConfirmationSetting: Option[
      zio.aws.lexmodelsv2.model.IntentConfirmationSetting
    ] = None,
    intentClosingSetting: Option[
      zio.aws.lexmodelsv2.model.IntentClosingSetting
    ] = None,
    inputContexts: Option[Iterable[zio.aws.lexmodelsv2.model.InputContext]] =
      None,
    outputContexts: Option[Iterable[zio.aws.lexmodelsv2.model.OutputContext]] =
      None,
    kendraConfiguration: Option[zio.aws.lexmodelsv2.model.KendraConfiguration] =
      None,
    botId: Id,
    botVersion: DraftBotVersion,
    localeId: LocaleId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest = {
    import UpdateIntentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
      .builder()
      .intentId(Id.unwrap(intentId): java.lang.String)
      .intentName(Name.unwrap(intentName): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        parentIntentSignature.map(value =>
          IntentSignature.unwrap(value): java.lang.String
        )
      )(_.parentIntentSignature)
      .optionallyWith(
        sampleUtterances.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sampleUtterances)
      .optionallyWith(dialogCodeHook.map(value => value.buildAwsValue()))(
        _.dialogCodeHook
      )
      .optionallyWith(fulfillmentCodeHook.map(value => value.buildAwsValue()))(
        _.fulfillmentCodeHook
      )
      .optionallyWith(
        slotPriorities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.slotPriorities)
      .optionallyWith(
        intentConfirmationSetting.map(value => value.buildAwsValue())
      )(_.intentConfirmationSetting)
      .optionallyWith(intentClosingSetting.map(value => value.buildAwsValue()))(
        _.intentClosingSetting
      )
      .optionallyWith(
        inputContexts.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.inputContexts)
      .optionallyWith(
        outputContexts.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.outputContexts)
      .optionallyWith(kendraConfiguration.map(value => value.buildAwsValue()))(
        _.kendraConfiguration
      )
      .botId(Id.unwrap(botId): java.lang.String)
      .botVersion(DraftBotVersion.unwrap(botVersion): java.lang.String)
      .localeId(LocaleId.unwrap(localeId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly =
    zio.aws.lexmodelsv2.model.UpdateIntentRequest.wrap(buildAwsValue())
}
object UpdateIntentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.UpdateIntentRequest =
      zio.aws.lexmodelsv2.model.UpdateIntentRequest(
        intentId,
        intentName,
        description.map(value => value),
        parentIntentSignature.map(value => value),
        sampleUtterances.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dialogCodeHook.map(value => value.asEditable),
        fulfillmentCodeHook.map(value => value.asEditable),
        slotPriorities.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        intentConfirmationSetting.map(value => value.asEditable),
        intentClosingSetting.map(value => value.asEditable),
        inputContexts.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        outputContexts.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        kendraConfiguration.map(value => value.asEditable),
        botId,
        botVersion,
        localeId
      )
    def intentId: Id
    def intentName: Name
    def description: Option[Description]
    def parentIntentSignature: Option[IntentSignature]
    def sampleUtterances
        : Option[List[zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly]]
    def dialogCodeHook
        : Option[zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly]
    def fulfillmentCodeHook
        : Option[zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly]
    def slotPriorities
        : Option[List[zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly]]
    def intentConfirmationSetting
        : Option[zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly]
    def intentClosingSetting
        : Option[zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly]
    def inputContexts
        : Option[List[zio.aws.lexmodelsv2.model.InputContext.ReadOnly]]
    def outputContexts
        : Option[List[zio.aws.lexmodelsv2.model.OutputContext.ReadOnly]]
    def kendraConfiguration
        : Option[zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly]
    def botId: Id
    def botVersion: DraftBotVersion
    def localeId: LocaleId
    def getIntentId: ZIO[Any, Nothing, Id] = ZIO.succeed(intentId)
    def getIntentName: ZIO[Any, Nothing, Name] = ZIO.succeed(intentName)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getParentIntentSignature: ZIO[Any, AwsError, IntentSignature] =
      AwsError.unwrapOptionField("parentIntentSignature", parentIntentSignature)
    def getSampleUtterances: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly
    ]] = AwsError.unwrapOptionField("sampleUtterances", sampleUtterances)
    def getDialogCodeHook: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly
    ] = AwsError.unwrapOptionField("dialogCodeHook", dialogCodeHook)
    def getFulfillmentCodeHook: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly
    ] = AwsError.unwrapOptionField("fulfillmentCodeHook", fulfillmentCodeHook)
    def getSlotPriorities: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly
    ]] = AwsError.unwrapOptionField("slotPriorities", slotPriorities)
    def getIntentConfirmationSetting: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly
    ] = AwsError.unwrapOptionField(
      "intentConfirmationSetting",
      intentConfirmationSetting
    )
    def getIntentClosingSetting: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly
    ] = AwsError.unwrapOptionField("intentClosingSetting", intentClosingSetting)
    def getInputContexts: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.InputContext.ReadOnly
    ]] = AwsError.unwrapOptionField("inputContexts", inputContexts)
    def getOutputContexts: ZIO[Any, AwsError, List[
      zio.aws.lexmodelsv2.model.OutputContext.ReadOnly
    ]] = AwsError.unwrapOptionField("outputContexts", outputContexts)
    def getKendraConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("kendraConfiguration", kendraConfiguration)
    def getBotId: ZIO[Any, Nothing, Id] = ZIO.succeed(botId)
    def getBotVersion: ZIO[Any, Nothing, DraftBotVersion] =
      ZIO.succeed(botVersion)
    def getLocaleId: ZIO[Any, Nothing, LocaleId] = ZIO.succeed(localeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ) extends zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly {
    override val intentId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.intentId())
    override val intentName: Name =
      zio.aws.lexmodelsv2.model.primitives.Name(impl.intentName())
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Description(value))
    override val parentIntentSignature: Option[IntentSignature] = scala
      .Option(impl.parentIntentSignature())
      .map(value => zio.aws.lexmodelsv2.model.primitives.IntentSignature(value))
    override val sampleUtterances
        : Option[List[zio.aws.lexmodelsv2.model.SampleUtterance.ReadOnly]] =
      scala
        .Option(impl.sampleUtterances())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lexmodelsv2.model.SampleUtterance.wrap(item)
          }.toList
        )
    override val dialogCodeHook
        : Option[zio.aws.lexmodelsv2.model.DialogCodeHookSettings.ReadOnly] =
      scala
        .Option(impl.dialogCodeHook())
        .map(value =>
          zio.aws.lexmodelsv2.model.DialogCodeHookSettings.wrap(value)
        )
    override val fulfillmentCodeHook: Option[
      zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.ReadOnly
    ] = scala
      .Option(impl.fulfillmentCodeHook())
      .map(value =>
        zio.aws.lexmodelsv2.model.FulfillmentCodeHookSettings.wrap(value)
      )
    override val slotPriorities
        : Option[List[zio.aws.lexmodelsv2.model.SlotPriority.ReadOnly]] = scala
      .Option(impl.slotPriorities())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lexmodelsv2.model.SlotPriority.wrap(item)
        }.toList
      )
    override val intentConfirmationSetting
        : Option[zio.aws.lexmodelsv2.model.IntentConfirmationSetting.ReadOnly] =
      scala
        .Option(impl.intentConfirmationSetting())
        .map(value =>
          zio.aws.lexmodelsv2.model.IntentConfirmationSetting.wrap(value)
        )
    override val intentClosingSetting
        : Option[zio.aws.lexmodelsv2.model.IntentClosingSetting.ReadOnly] =
      scala
        .Option(impl.intentClosingSetting())
        .map(value =>
          zio.aws.lexmodelsv2.model.IntentClosingSetting.wrap(value)
        )
    override val inputContexts
        : Option[List[zio.aws.lexmodelsv2.model.InputContext.ReadOnly]] = scala
      .Option(impl.inputContexts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lexmodelsv2.model.InputContext.wrap(item)
        }.toList
      )
    override val outputContexts
        : Option[List[zio.aws.lexmodelsv2.model.OutputContext.ReadOnly]] = scala
      .Option(impl.outputContexts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lexmodelsv2.model.OutputContext.wrap(item)
        }.toList
      )
    override val kendraConfiguration
        : Option[zio.aws.lexmodelsv2.model.KendraConfiguration.ReadOnly] = scala
      .Option(impl.kendraConfiguration())
      .map(value => zio.aws.lexmodelsv2.model.KendraConfiguration.wrap(value))
    override val botId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.botId())
    override val botVersion: DraftBotVersion =
      zio.aws.lexmodelsv2.model.primitives.DraftBotVersion(impl.botVersion())
    override val localeId: LocaleId =
      zio.aws.lexmodelsv2.model.primitives.LocaleId(impl.localeId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateIntentRequest
  ): zio.aws.lexmodelsv2.model.UpdateIntentRequest.ReadOnly = new Wrapper(impl)
}
